package java.awt;

import sun.java2d.SunGraphicsEnvironment;
import sun.font.FontManagerFactory;
import java.util.Locale;
import java.awt.image.BufferedImage;
import sun.java2d.HeadlessGraphicsEnvironment;
import java.security.AccessController;
import sun.security.action.GetPropertyAction;

public abstract class GraphicsEnvironment
{
    private static GraphicsEnvironment localEnv;
    private static Boolean headless;
    private static Boolean defaultHeadless;
    
    protected GraphicsEnvironment() {
    }
    
    public static synchronized GraphicsEnvironment getLocalGraphicsEnvironment() {
        if (GraphicsEnvironment.localEnv == null) {
            GraphicsEnvironment.localEnv = createGE();
        }
        return GraphicsEnvironment.localEnv;
    }
    
    private static GraphicsEnvironment createGE() {
        String str = (String)AccessController.doPrivileged(new GetPropertyAction("java.awt.graphicsenv", null));
        GraphicsEnvironment ge;
        try {
            Class<Object> clazz;
            try {
                clazz = Class.forName(str);
            }
            catch (ClassNotFoundException ex) {
                clazz = Class.forName(str, true, ClassLoader.getSystemClassLoader());
            }
            ge = (Object)clazz.newInstance();
            if (isHeadless()) {
                ge = new HeadlessGraphicsEnvironment(ge);
            }
        }
        catch (ClassNotFoundException ex2) {
            throw new Error("Could not find class: " + str);
        }
        catch (InstantiationException ex3) {
            throw new Error("Could not instantiate Graphics Environment: " + str);
        }
        catch (IllegalAccessException ex4) {
            throw new Error("Could not access Graphics Environment: " + str);
        }
        return ge;
    }
    
    public static boolean isHeadless() {
        return getHeadlessProperty();
    }
    
    static String getHeadlessMessage() {
        if (GraphicsEnvironment.headless == null) {
            getHeadlessProperty();
        }
        return (GraphicsEnvironment.defaultHeadless != Boolean.TRUE) ? null : "\nNo X11 DISPLAY variable was set, but this program performed an operation which requires it.";
    }
    
    private static boolean getHeadlessProperty() {
        if (GraphicsEnvironment.headless == null) {
            AccessController.doPrivileged(()/*  */ -> {
                String s = System.getProperty("java.awt.headless");
                if (s == null) {
                    if (System.getProperty("javaplugin.version") != null) {
                        Boolean b3 = GraphicsEnvironment.headless = (GraphicsEnvironment.defaultHeadless = Boolean.FALSE);
                    }
                    else {
                        String s2 = System.getProperty("os.name");
                        if (s2.contains("OS X") && "sun.awt.HToolkit".equals(System.getProperty("awt.toolkit"))) {
                            Boolean b2 = GraphicsEnvironment.headless = (GraphicsEnvironment.defaultHeadless = Boolean.TRUE);
                        }
                        else {
                            String s3 = System.getenv("DISPLAY");
                            Boolean b = GraphicsEnvironment.headless = (GraphicsEnvironment.defaultHeadless = Boolean.valueOf(("Linux".equals(s2) || "SunOS".equals(s2) || "FreeBSD".equals(s2) || "NetBSD".equals(s2) || "OpenBSD".equals(s2) || "AIX".equals(s2)) && (s3 == null || s3.trim().isEmpty())));
                        }
                    }
                }
                else {
                    GraphicsEnvironment.headless = Boolean.valueOf(s);
                }
                return null;
            });
        }
        return (boolean)GraphicsEnvironment.headless;
    }
    
    static void checkHeadless() throws HeadlessException {
        if (isHeadless()) {
            throw new HeadlessException();
        }
        return;
    }
    
    public boolean isHeadlessInstance() {
        return getHeadlessProperty();
    }
    
    public abstract GraphicsDevice[] getScreenDevices() throws HeadlessException;
    
    public abstract GraphicsDevice getDefaultScreenDevice() throws HeadlessException;
    
    public abstract Graphics2D createGraphics(BufferedImage p0);
    
    public abstract Font[] getAllFonts();
    
    public abstract String[] getAvailableFontFamilyNames();
    
    public abstract String[] getAvailableFontFamilyNames(Locale p0);
    
    public boolean registerFont(Font font) {
        if (font == null) {
            throw new NullPointerException("font cannot be null.");
        }
        return FontManagerFactory.getInstance().registerFont(font);
    }
    
    public void preferLocaleFonts() {
        FontManagerFactory.getInstance().preferLocaleFonts();
    }
    
    public void preferProportionalFonts() {
        FontManagerFactory.getInstance().preferProportionalFonts();
    }
    
    public Point getCenterPoint() throws HeadlessException {
        Rectangle usableBounds = SunGraphicsEnvironment.getUsableBounds(this.getDefaultScreenDevice());
        return new Point(usableBounds.width / 2 + usableBounds.x, usableBounds.height / 2 + usableBounds.y);
    }
    
    public Rectangle getMaximumWindowBounds() throws HeadlessException {
        return SunGraphicsEnvironment.getUsableBounds(this.getDefaultScreenDevice());
    }
}
